package com.example.moviestudio

import androidx.room.ColumnInfo
import androidx.room.Embedded
import androidx.room.Entity
import androidx.room.ForeignKey
import androidx.room.Index
import androidx.room.Junction
import androidx.room.PrimaryKey
import androidx.room.Relation


// ------------------------------------------------------------------------------------------------
// --- Movie
// ------------------------------------------------------------------------------------------------

@Entity(tableName = "movies")
data class Movie(
    @PrimaryKey(autoGenerate = false)
    val id: Long = 0,
    val name: String,
    @ColumnInfo(name = "release_date") val releaseDate: String,
    val poster: String,
    val description: String,
    var actors: String, // Separated by comma.
    var genres: String // Separated by comma.
)

data class MovieWithGenres(
    @Embedded val movie: Movie,
    @Relation(
        parentColumn = "movieId",
        entityColumn = "genreId",
        associateBy = Junction(GenreMovieCrossRef::class)
    )
    val genres: List<Genre>
)


// ------------------------------------------------------------------------------------------------
// --- Genre
// ------------------------------------------------------------------------------------------------

@Entity
data class Genre(
    @PrimaryKey val id: Long,
    val name: String
)

// ------------------------------------------------------------------------------------------------
// --- GenreMovieCrossRef
// ------------------------------------------------------------------------------------------------

@Entity(
    primaryKeys = ["genreId", "movieId"],
    foreignKeys = [
        ForeignKey(
            entity = Genre::class,
            parentColumns = ["id"],
            childColumns = ["genreId"],
            onDelete = ForeignKey.CASCADE
        ),
        ForeignKey(
            entity = Movie::class,
            parentColumns = ["id"],
            childColumns = ["movie_id"],
            onDelete = ForeignKey.CASCADE
        ),
    ]
)
data class GenreMovieCrossRef(
    val genreId: Long,
    val movieId: Long
)

// ------------------------------------------------------------------------------------------------
// --- UserRating
// ------------------------------------------------------------------------------------------------

@Entity(
    foreignKeys = [ForeignKey(
        entity = Movie::class,
        parentColumns = ["id"],
        childColumns = ["movie_id"],
        onDelete = ForeignKey.CASCADE
    )],
    tableName = "ratings",
    indices = [Index(value = ["movie_id"], unique = true)]
)
data class UserRating(
    @PrimaryKey(autoGenerate = true)
    val id: Long = 0,
    var rating: Int = 1,
    var comment: String = "",
    @ColumnInfo(name = "movie_id")
    var movieId: Long
)

