import com.example.moviestudio.Movie
import retrofit2.Retrofit
import retrofit2.converter.gson.GsonConverterFactory
import retrofit2.http.GET
import retrofit2.http.Path
import retrofit2.http.Query

//BaseUrl
private val baseUrl: String = "https://api.themoviedb.org/3/"
private val key = "5c2f363d23b603530fd9f96a4678cf6f"

private val retrofit = Retrofit
    .Builder()
    .baseUrl(baseUrl)
    .build()

interface APIService {
    @GET("search/movie")
    suspend fun getMovies(
        @Query("query") query: String,
        @Query("language") language: String = "fr-FR",
        @Query("api_key") apiKey: String = key
    ): APIResults

    @GET("movie/{id}")
    suspend fun getMovieGenres(
        @Path("id") id: Int,
        @Query("language") language: String = "fr-FR",
        @Query("api_key") apiKey: String = key
    ): APIResultMovieGenres

    @GET("movie/{id}/casts")
    suspend fun getMovieActors(
        @Path("id") id: Int,
        @Query("api_key") apiKey: String = key
    ): APIResultMovieActors
}

object MovieAPI {
    val service: APIService by lazy {
        retrofit.newBuilder()
            .addConverterFactory(GsonConverterFactory.create())
            .build()
            .create(APIService::class.java)
    }
}


data class APIResults(
    val page: Int,
    val results: List<MovieResult>,
    val totalPages: Int,
    val totalResults: Int
)

data class APIResultMovieGenres(
    val genres: List<Genre>
)

data class Genre(
    val name: String
)

data class APIResultMovieActors(
    val cast: List<Actor>
)

data class Actor(
    val name: String,
    val known_for_department: String
)

data class MovieResult(
    val id: Int,
    val title: String,
    val overview: String,
    val release_date: String,
    val poster_path: String
)
