package com.example.moviestudio.database

import androidx.lifecycle.LiveData
import androidx.room.Dao
import androidx.room.Insert
import androidx.room.OnConflictStrategy
import androidx.room.Query
import androidx.room.Update
import com.example.moviestudio.Movie
import kotlinx.coroutines.flow.MutableStateFlow

@Dao
interface MovieDao {
    @Query("SELECT * FROM movies")
    fun getAllMovies(): List<Movie>

    @Insert(onConflict = OnConflictStrategy.IGNORE)
    suspend fun insertMovie(movieEntity: Movie)

    @Query("SELECT * FROM movies WHERE (:name = '' OR name LIKE '%' || :name || '%') AND (:date = '' OR release_date LIKE '%' || :date || '%') AND (:actors = '' OR actors LIKE '%' || :actors || '%') AND (:genres = '' OR genres LIKE '%' || :genres || '%')")
    suspend fun getMoviesByFilters(name: String, date: String, actors: String, genres: String): List<Movie>

    @Query("DELETE FROM movies WHERE id = :movieId")
    suspend fun deleteMovie(movieId: Long)

    @Query("DELETE FROM movies")
    suspend fun deleteMovies()
}
