package com.example.moviestudio.ui.components

import android.util.Log
import androidx.compose.foundation.layout.RowScope
import androidx.compose.material3.Icon
import androidx.compose.material3.NavigationBar
import androidx.compose.material3.NavigationBarItem
import androidx.compose.material3.NavigationBarItemDefaults
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.navigation.NavController
import com.example.moviestudio.ui.theme.dark
import com.example.moviestudio.ui.theme.main

@Composable
fun BottomNavigation(navController: NavController) {
    val items = listOf(
        BottomNavItem.Library,
        BottomNavItem.Search,
        BottomNavItem.Settings,
    )

    NavigationBar(containerColor = dark) {
        items.forEach { item ->
            AddItem(
                screen = item,
                navController = navController
            )
        }
    }
}

@Composable
fun RowScope.AddItem(
    screen: BottomNavItem,
    navController: NavController
) {
    val isSelected = navController.currentDestination?.route == screen.activity

    NavigationBarItem(
        label = {
            Text(text = screen.title, color = Color.White)
        },
        icon = {
            Icon(
                painterResource(id = screen.icon),
                contentDescription = screen.title,
                tint = Color.White
            )
        },
        selected = isSelected,
        alwaysShowLabel = true,
        onClick = {
            navController.navigate(screen.activity)
        },
        colors = NavigationBarItemDefaults.colors(
            indicatorColor = main
        )
    )
}
