package com.example.moviestudio.ui.components

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Divider
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalDensity
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.compose.ui.zIndex
import coil.compose.AsyncImage
import com.example.moviestudio.Movie
import com.example.moviestudio.R
import com.example.moviestudio.ui.theme.second

@Composable
fun MovieCardLibrary(
    movie: Movie,
    onKnowMoreClick: () -> Unit,
    onDeleteClick: () -> Unit
) {
    var moreInformations = stringResource(id = R.string.library_button_more_informations)

    var url = "https://image.tmdb.org/t/p/w500/" + movie.poster
    Box(
        modifier = Modifier
            .fillMaxWidth()
            .padding(16.dp)
    ) {
        Row(
            modifier = Modifier
                .fillMaxWidth()
        ) {
            // Movie poster on the left
            AsyncImage(
                model = url,
                contentDescription = "Movie Poster",
                modifier = Modifier
                    .height(220.dp)
                    .width(120.dp)
                    .clip(MaterialTheme.shapes.medium),
                contentScale = ContentScale.Crop
            )

            // Movie details in the middle
            Column(
                modifier = Modifier
                    .fillMaxWidth()
                    .padding(start = 16.dp)
            ) {
                Text(
                    text = movie.name,
                    fontSize = 20.sp,
                    fontWeight = FontWeight.Bold,
                    color = Color.White,
                    modifier = Modifier
                        .fillMaxWidth(0.8f)
                )
                Text(
                    text = movie.description.take(120) + "...",
                    fontSize = 16.sp,
                    color = Color.White,
                    textAlign = TextAlign.Left,
                    modifier = Modifier.padding(top = 6.dp)
                )

                // Buttons
                Row(
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(top = 8.dp),
                    horizontalArrangement = Arrangement.SpaceBetween
                ) {
                    Column(
                        modifier = Modifier.fillMaxWidth(1f)
                    ) {
                        Button(
                            onClick = onKnowMoreClick,
                            modifier = Modifier.fillMaxWidth(1f),
                            colors = ButtonDefaults.buttonColors(containerColor = second)
                        ) {
                            Text(text = moreInformations)
                        }
                    }
                }
            }
        }

        // Trash icon in the top-right corner
        Icon(
            painter = painterResource(id = R.drawable.baseline_delete_24),
            contentDescription = "Delete",
            modifier = Modifier
                .padding(8.dp)
                .size(24.dp)
                .clickable { onDeleteClick() }
                .align(Alignment.TopEnd)
                .fillMaxWidth(0.2f),
            tint = Color.White,
        )
    }

    Spacer(modifier = Modifier.height(2.dp))
    Divider(
        color = Color.DarkGray,
        thickness = 0.001.dp,
        modifier = Modifier
            .fillMaxWidth()
            .padding(4.dp)
            .height(LocalDensity.current.density.dp)
    )
}
