package com.example.moviestudio.ui.components

import android.util.Log
import androidx.compose.foundation.Image
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Add
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Divider
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalDensity
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import coil.compose.AsyncImage
import com.example.moviestudio.Movie
import com.example.moviestudio.R
import com.example.moviestudio.ui.theme.second
import java.text.SimpleDateFormat
import java.util.Date
import java.util.Locale

@Composable
fun MovieCardSearch(
    movie: Movie,
    onKnowMoreClick: () -> Unit,
    onAddToLibraryClick: () -> Unit,
    added: Boolean
) {
    var pageName = stringResource(id = R.string.library_title)
    var txtMoreInformations = stringResource(id = R.string.library_button_more_informations)
    var added by remember { mutableStateOf(added) }
    var url = "https://image.tmdb.org/t/p/w500/" + movie.poster
    Box(
        modifier = Modifier
            .fillMaxWidth()
            .padding(16.dp)
    ) {
        Row() {
            AsyncImage(
                model = url,
                contentDescription = "Movie Poster",
                modifier = Modifier
                    .height(220.dp)
                    .width(120.dp)
                    .clip(MaterialTheme.shapes.medium),
                contentScale = ContentScale.Crop
            )

            // Movie details on the right
            Column(
                modifier = Modifier
                    .fillMaxWidth()
                    .padding(start = 16.dp)
            ) {
                Text(
                    text = movie.name,
                    fontSize = 20.sp,
                    fontWeight = FontWeight.Bold,
                    color = Color.White
                )
                Text(
                    text = movie.description.take(120) + "...",
                    fontSize = 16.sp,
                    color = Color.White,
                    textAlign = TextAlign.Left
                )

                // Buttons
                Row(
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(top = 8.dp),
                    horizontalArrangement = Arrangement.SpaceBetween
                ) {
                    Column(
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(top = 10.dp)
                    ) {
                        Button(
                            onClick = onKnowMoreClick,
                            modifier = Modifier.fillMaxWidth(),
                            colors = ButtonDefaults.buttonColors(containerColor = second)
                        ) {
                            Text(text = txtMoreInformations)
                        }

                        var btnColors = ButtonDefaults.buttonColors(containerColor = second)
                        if (added)
                            btnColors = ButtonDefaults.buttonColors(containerColor = Color.Gray)
                        Button(
                            onClick = {
                                if (!added) {
                                    onAddToLibraryClick()
                                    added = true
                                }
                            },
                            modifier = Modifier.fillMaxWidth(),
                            colors = btnColors
                        ) {
                            Text(text = pageName)
                            Icon(
                                imageVector = Icons.Default.Add,
                                contentDescription = null,
                                tint = Color.White
                            )
                        }

                    }
                }
            }
        }
    }
    Spacer(modifier = Modifier.height(2.dp))
    Divider(
        color = Color.LightGray,
        thickness = 0.01.dp,
        modifier = Modifier
            .fillMaxWidth()
            .height(LocalDensity.current.density.dp)
    )
}
