package com.example.moviestudio.ui.components

import android.annotation.SuppressLint
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.lazy.LazyRow
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.verticalScroll
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Close
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.TopAppBar
import androidx.compose.material3.TopAppBarDefaults
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalDensity
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import coil.compose.AsyncImage
import com.example.moviestudio.Movie
import com.example.moviestudio.R
import com.example.moviestudio.ui.theme.dark
import com.example.moviestudio.ui.theme.main
import com.example.moviestudio.ui.theme.third
import java.text.SimpleDateFormat
import java.util.Date
import java.util.Locale

@SuppressLint("UnusedMaterial3ScaffoldPaddingParameter")
@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun PreviewMovie(
    isModalVisible: Boolean,
    onCloseButtonClick: () -> Unit,
    movie: Movie
) {
    var modalTitle = stringResource(id = R.string.library_modal_movie_details_title)
    var txtReleaseDate = stringResource(id = R.string.modal_movie_details_release_date)
    var txtActors = stringResource(id = R.string.modal_movie_details_actors)
    var txtGenres = stringResource(id = R.string.modal_movie_details_genres)
    // UI-related variables:
    val density = LocalDensity.current.density
    var url = "https://image.tmdb.org/t/p/w500/" + movie.poster

    if (isModalVisible) {
        Scaffold(
            modifier = Modifier.fillMaxSize(),
            topBar = {
                TopAppBar(
                    colors = TopAppBarDefaults.smallTopAppBarColors(
                        containerColor = main,
                        titleContentColor = Color.White,
                    ),
                    title = {
                        Row(
                            modifier = Modifier.fillMaxWidth(),
                            horizontalArrangement = Arrangement.SpaceBetween,
                            verticalAlignment = Alignment.CenterVertically,
                        )
                        {
                            Text(text = modalTitle)
                            IconButton(onClick = onCloseButtonClick) {
                                Icon(
                                    imageVector = Icons.Default.Close,
                                    contentDescription = null,
                                    tint = Color.White
                                )
                            }
                        }
                    }
                )
            },
            content = {
                Column(
                    modifier = Modifier
                        .background(color = dark)
                        .fillMaxWidth()
                        .fillMaxHeight()
                        .padding(16.dp)
                        .verticalScroll(rememberScrollState()),
                    horizontalAlignment = Alignment.CenterHorizontally
                ) {
                    Row(
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(bottom = 8.dp),
                        horizontalArrangement = Arrangement.SpaceBetween
                    ) {
                        IconButton(onClick = {}) {
                            Icon(imageVector = Icons.Default.Close, contentDescription = null)
                        }
                    }

                    Text(movie.name, fontSize = 26.sp, color = Color.White)
                    Text("${txtReleaseDate} ${formatDate(movie.releaseDate)}", fontSize = 16.sp, color = Color.White)

                    Spacer(modifier = Modifier.height(16.dp))
                    AsyncImage(
                        model = url,
                        contentDescription = "Movie Poster",
                        modifier = Modifier
                            .width((80 * density).dp)
                            .height((120 * density).dp)
                            .clip(shape = MaterialTheme.shapes.medium),
                        contentScale = ContentScale.Crop
                    )

                    Spacer(modifier = Modifier.height(16.dp))

                    Text(
                        movie.description,
                        fontSize = 16.sp,
                        textAlign = TextAlign.Justify,
                        color = Color.White
                    )
                    Spacer(modifier = Modifier.height(8.dp))
                    Column(
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(4.dp)
                    ) {
                        // Actors Section
                        Text(
                            txtActors,
                            fontSize = 16.sp,
                            textAlign = TextAlign.Start,
                            color = Color.White
                        )
                        LazyRow(modifier = Modifier.padding(4.dp), userScrollEnabled = true) {
                            items(movie.actors.split(',')) { actor ->
                                Box(
                                    modifier = Modifier
                                        .padding(6.dp)
                                        .border(1.dp, third, MaterialTheme.shapes.medium)
                                ) {
                                    Text(
                                        text = actor,
                                        color = Color.White,
                                        fontSize = 16.sp,
                                        modifier = Modifier
                                            .padding(8.dp)
                                    )
                                }
                            }
                        }
                        Spacer(modifier = Modifier.height(8.dp))

                        // Genres Section
                        Text(
                            txtGenres,
                            fontSize = 16.sp,
                            textAlign = TextAlign.Start,
                            color = Color.White
                        )
                        LazyRow(modifier = Modifier.padding(4.dp), userScrollEnabled = true) {
                            items(movie.genres.split(',')) { genre ->
                                Box(
                                    modifier = Modifier
                                        .padding(8.dp)
                                        .border(1.dp, third, MaterialTheme.shapes.medium)
                                ) {
                                    Text(
                                        text = genre,
                                        color = Color.White,
                                        fontSize = 16.sp,
                                        modifier = Modifier
                                            .padding(8.dp)
                                    )
                                }
                            }
                        }
                        Spacer(modifier = Modifier.height(55.dp))
                    }
                }
            }
        )
    }
}
