package com.example.moviestudio.ui.components

import android.content.Context
import android.util.Log
import android.widget.Toast
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.text.KeyboardActions
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.input.ImeAction
import androidx.compose.ui.unit.dp
import com.example.moviestudio.R
import com.example.moviestudio.ui.theme.second
import kotlinx.coroutines.launch

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun SearchMovieBar(
    searchQuery: String,
    onSearchQueryChange: (String) -> Unit,
    onSearchMovie: () -> Unit,
    onClearClick: () -> Unit
) {
    val search = stringResource(id = R.string.search_textbox)
    val context = LocalContext.current
    val toastTextGetData = stringResource(id = R.string.search_toaster_loading)
    val toastTextClearSearch = stringResource(id = R.string.search_clear_search)
    val toastTextSearchIsEmpty = stringResource(id = R.string.search_query_is_empty)
    Row {
        Column {

            Button(
                colors = ButtonDefaults.buttonColors(containerColor = second),
                modifier = Modifier
                    .width(80.dp)
                    .padding(top = 75.dp)
                    .padding(start = 5.dp, end = 5.dp),
                onClick = {
                    if (searchQuery.isEmpty()) {
                        Toast.makeText(context, toastTextSearchIsEmpty, Toast.LENGTH_LONG).show()
                    } else {
                        onSearchMovie()
                        Toast.makeText(context, toastTextGetData, Toast.LENGTH_LONG).show()
                    }
                }) {
                Icon(
                    painterResource(id = R.drawable.baseline_search_24),
                    contentDescription = "Search",
                    tint = Color.White
                )
            }
            Button(
                colors = ButtonDefaults.buttonColors(containerColor = second),
                modifier = Modifier
                    .width(80.dp)
                    .padding(start = 5.dp, end = 5.dp),
                onClick = {
                    onClearClick()
                    Toast.makeText(context, toastTextClearSearch, Toast.LENGTH_SHORT).show()
                }) {
                Icon(
                    painterResource(id = R.drawable.baseline_clear_24),
                    contentDescription = "Clear",
                    tint = Color.White
                )
            }
        }
        OutlinedTextField(
            value = searchQuery,
            onValueChange = { onSearchQueryChange(it) },
            label = { Text(search) },
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 70.dp)
                .padding(8.dp),
            textStyle = TextStyle(color = Color.White),
            keyboardOptions = KeyboardOptions.Default.copy(
                imeAction = ImeAction.Done
            ),
            keyboardActions = KeyboardActions(
                onDone = {
                    onSearchMovie()
                }
            )
        )
    }
}

