package com.example.moviestudio.ui.components

import android.annotation.SuppressLint
import android.util.Log
import android.widget.Toast
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.lazy.LazyRow
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.verticalScroll
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Close
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.DropdownMenu
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.TopAppBar
import androidx.compose.material3.TopAppBarDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.platform.LocalDensity
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.lifecycle.viewmodel.compose.viewModel
import coil.compose.AsyncImage
import com.example.moviestudio.Movie
import com.example.moviestudio.R
import com.example.moviestudio.UserRating
import com.example.moviestudio.ui.theme.dark
import com.example.moviestudio.ui.theme.main
import com.example.moviestudio.ui.theme.second
import com.example.moviestudio.ui.theme.third
import com.example.moviestudio.viewmodels.ShowMovieViewModel
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import java.text.SimpleDateFormat
import java.util.Date
import java.util.Locale

@SuppressLint("UnusedMaterial3ScaffoldPaddingParameter")
@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun ShowMovie(
    isModalVisible: Boolean,
    onCloseButtonClick: () -> Unit,
    movie: Movie
) {
    var modalTitle = stringResource(id = R.string.library_modal_movie_details_title)
    var txtReleaseDate = stringResource(id = R.string.modal_movie_details_release_date)
    var txtActors = stringResource(id = R.string.modal_movie_details_actors)
    var txtGenres = stringResource(id = R.string.modal_movie_details_genres)
    var txtNote = stringResource(id = R.string.library_modal_movie_details_note)
    var txtComment = stringResource(id = R.string.library_modal_movie_details_comment)
    var txtSave = stringResource(id = R.string.button_text)
    val toastText = stringResource(id = R.string.library_modal_movie_details_toaster_save)
    val context = LocalContext.current

    val viewModel = viewModel<ShowMovieViewModel>()
    var url = "https://image.tmdb.org/t/p/w500/" + movie.poster

    // UI-related variables:
    val density = LocalDensity.current.density

    if (isModalVisible) {
        Scaffold(
            modifier = Modifier.fillMaxSize(),
            topBar = {
                TopAppBar(
                    colors = TopAppBarDefaults.smallTopAppBarColors(
                        containerColor = main,
                        titleContentColor = Color.White,
                    ),
                    title = {
                        Row(
                            modifier = Modifier.fillMaxWidth(),
                            horizontalArrangement = Arrangement.SpaceBetween,
                            verticalAlignment = Alignment.CenterVertically,
                        )
                        {
                            Text(text = modalTitle)
                            IconButton(onClick = onCloseButtonClick) {
                                Icon(
                                    imageVector = Icons.Default.Close,
                                    contentDescription = null,
                                    tint = Color.White
                                )
                            }
                        }
                    }
                )
            },
            content = {
                Column(
                    modifier = Modifier
                        .background(color = dark)
                        .fillMaxWidth()
                        .padding(16.dp)
                        .verticalScroll(rememberScrollState()),
                    horizontalAlignment = Alignment.CenterHorizontally
                ) {
                    Row(
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(bottom = 8.dp),
                        horizontalArrangement = Arrangement.SpaceBetween
                    ) {
                        IconButton(onClick = {}) {
                            Icon(imageVector = Icons.Default.Close, contentDescription = null)
                        }
                    }

                    Text(movie.name, fontSize = 26.sp, color = Color.White)
                    Text(
                        "${txtReleaseDate} ${formatDate(movie.releaseDate)}",
                        fontSize = 16.sp,
                        color = Color.White
                    )

                    Spacer(modifier = Modifier.height(16.dp))
                    AsyncImage(
                        model = url,
                        contentDescription = "Movie Poster",
                        modifier = Modifier
                            .width((80 * density).dp)
                            .height((120 * density).dp)
                            .clip(shape = MaterialTheme.shapes.medium),
                        contentScale = ContentScale.Crop
                    )

                    Spacer(modifier = Modifier.height(16.dp))

                    Text(
                        movie.description,
                        fontSize = 16.sp,
                        textAlign = TextAlign.Justify,
                        color = Color.White
                    )
                    Spacer(modifier = Modifier.height(8.dp))
                    Column(
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(4.dp)
                    ) {
                        // Actors Section
                        Text(
                            txtActors,
                            fontSize = 16.sp,
                            textAlign = TextAlign.Start,
                            color = Color.White
                        )
                        LazyRow(modifier = Modifier.padding(4.dp), userScrollEnabled = true) {
                            items(movie.actors.split(',')) { actor ->
                                Box(
                                    modifier = Modifier
                                        .padding(6.dp)
                                        .border(1.dp, third, MaterialTheme.shapes.medium)
                                ) {
                                    Text(
                                        text = actor,
                                        color = Color.White,
                                        fontSize = 16.sp,
                                        modifier = Modifier
                                            .padding(8.dp)
                                    )
                                }
                            }
                        }
                        Spacer(modifier = Modifier.height(8.dp))

                        // Genres Section
                        Text(
                            txtGenres,
                            fontSize = 16.sp,
                            textAlign = TextAlign.Start,
                            color = Color.White
                        )
                        LazyRow(modifier = Modifier.padding(4.dp), userScrollEnabled = true) {
                            items(movie.genres.split(',')) { genre ->
                                Box(
                                    modifier = Modifier
                                        .padding(6.dp)
                                        .border(1.dp, third, MaterialTheme.shapes.medium)
                                ) {
                                    Text(
                                        text = genre,
                                        color = Color.White,
                                        fontSize = 16.sp,
                                        modifier = Modifier
                                            .padding(8.dp)
                                    )
                                }
                            }
                        }
                    }

                    Column(
                        horizontalAlignment = Alignment.CenterHorizontally,
                        verticalArrangement = Arrangement.Center,
                    ) {
                        Row(
                            horizontalArrangement = Arrangement.spacedBy(5.dp),
                            verticalAlignment = Alignment.CenterVertically,
                        ) {

                            Column(
                                verticalArrangement = Arrangement.spacedBy(4.dp),
                                horizontalAlignment = Alignment.Start
                            ) {
                                Text(
                                    text = txtNote,
                                    color = Color.White,
                                    fontSize = 16.sp,
                                    modifier = Modifier.padding(6.dp, 4.dp, 6.dp, 4.dp)
                                )

                                Column {
                                    Box(
                                        modifier = Modifier
                                            .width(65.dp)
                                            .padding(6.dp, 8.dp, 6.dp, 8.dp)
                                            .background(dark)
                                            .clickable { viewModel.updateIsDropdownExpanded(true) }
                                            .border(1.dp, Color.White, MaterialTheme.shapes.medium)
                                    ) {
                                        Text(
                                            text = viewModel.rating.value.rating.toString(),
                                            color = Color.White,
                                            modifier = Modifier.padding(16.dp)
                                        )
                                    }

                                    DropdownMenu(
                                        expanded = viewModel.isDropdownExpanded,
                                        onDismissRequest = {
                                            viewModel.updateIsDropdownExpanded(
                                                false
                                            )
                                        },
                                        modifier = Modifier
                                            .width(65.dp)
                                            .background(dark)
                                    ) {
                                        for (i in 1..5) {
                                            DropdownMenuItem(
                                                onClick = {
                                                    viewModel.updateRatingValue(i)
                                                    viewModel.updateIsDropdownExpanded(false)
                                                },
                                                text = {
                                                    Text(i.toString(), color = Color.White)
                                                })
                                        }
                                    }
                                }
                            }

                            Column(
                                verticalArrangement = Arrangement.spacedBy(4.dp),
                                horizontalAlignment = Alignment.Start
                            ) {
                                Text(
                                    text = txtComment,
                                    color = Color.White,
                                    fontSize = 16.sp,
                                    modifier = Modifier.padding(4.dp)
                                )

                                // Text field to input a comment
                                OutlinedTextField(
                                    value = viewModel.rating.value.comment,
                                    onValueChange = { viewModel.updateCommentValue(it) },
                                    modifier = Modifier
                                        .fillMaxWidth()
                                        .padding(4.dp)
                                        .border(1.dp, Color.White, MaterialTheme.shapes.medium),
                                    textStyle = TextStyle(color = Color.White)
                                )
                            }
                        }

                        // Button to save
                        Button(
                            onClick = {
                                viewModel.insertRating(movie)
                                Toast.makeText(context, toastText, Toast.LENGTH_SHORT).show()
                            },
                            modifier = Modifier
                                .fillMaxWidth()
                                .padding(2.dp),
                            colors = ButtonDefaults.buttonColors(containerColor = second)
                        ) {
                            Text(txtSave)
                        }
                        Spacer(modifier = Modifier.height(65.dp))
                    }
                }
            }
        )
    }
}

fun formatDate(inputDate: String): String {
    val inputFormat = SimpleDateFormat("yyyy-MM-dd", Locale.getDefault())
    val outputFormat = SimpleDateFormat("EEEE dd MMMM yyyy", Locale("fr", "FR"))

    try {
        val date: Date = inputFormat.parse(inputDate)
        return outputFormat.format(date)
    } catch (e: Exception) {
        e.printStackTrace()
        return inputDate
    }
}
