package com.example.moviestudio.ui.screens

import android.annotation.SuppressLint
import android.util.Log
import android.widget.Toast
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.TopAppBar
import androidx.compose.material3.TopAppBarDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.modifier.modifierLocalConsumer
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.lifecycle.viewmodel.compose.viewModel
import androidx.navigation.NavController
import com.example.moviestudio.R
import com.example.moviestudio.ui.components.BottomNavigation
import com.example.moviestudio.ui.components.MovieCardSearch
import com.example.moviestudio.ui.components.PreviewMovie
import com.example.moviestudio.ui.components.SearchMovieBar
import com.example.moviestudio.ui.theme.dark
import com.example.moviestudio.ui.theme.main
import com.example.moviestudio.viewmodels.SearchMovieViewModel
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch

@SuppressLint("UnusedMaterial3ScaffoldPaddingParameter", "UnrememberedMutableState")
@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun SearchMovie(navController: NavController) {
    val appName = stringResource(id = R.string.app_name)
    val pageName = stringResource(id = R.string.search_undertitle)
    val moviesNotFound = stringResource(id = R.string.search_result_empty)
    val searchingMovie = stringResource(id = R.string.search_is_searching)

    val viewModel = viewModel<SearchMovieViewModel>()

    val movieFlow by viewModel.movieFlow.collectAsState()

    val context = LocalContext.current
    val toastText = stringResource(id = R.string.search_toaster_loading)

    Scaffold(modifier = Modifier,
        topBar = {
            if (!viewModel.isPopupVisible) {
                TopAppBar(colors = TopAppBarDefaults.smallTopAppBarColors(
                    containerColor = main,
                    titleContentColor = Color.White,
                ), title = {
                    Column {
                        Text(text = appName, fontSize = 24.sp)
                        Text(text = pageName, fontSize = 16.sp)
                    }
                })
            }
        },
        content = {
            Column(
                modifier = Modifier
                    .background(dark)
                    .fillMaxWidth()
                    .padding(4.dp),
                horizontalAlignment = Alignment.CenterHorizontally
            ) {
                if (!viewModel.isPopupVisible) {
                    SearchMovieBar(
                        viewModel.searchQuery,
                        onSearchQueryChange = { viewModel.updateSearchQuery(it) },
                        onSearchMovie = {
                            viewModel.clearMovieList()
                            viewModel.isSearchingMovie = true
                            viewModel.searchMovies()
                            Toast.makeText(context, toastText, Toast.LENGTH_LONG).show()
                        },
                        onClearClick = {
                            viewModel.clearInput()
                            viewModel.clearMovieList()
                        }
                    )
                }

                if (movieFlow.isEmpty() && !viewModel.isSearchingMovie) {
                    Text(
                        text = moviesNotFound,
                        color = Color.Gray,
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(8.dp)
                    )
                } else if (viewModel.isSearchingMovie) {
                    Text(
                        text = searchingMovie,
                        color = Color.Gray,
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(8.dp)
                    )
                }

                LazyColumn(
                    modifier = Modifier
                        .fillMaxWidth()
                        .weight(1f)
                ) {
                    items(movieFlow) { movie ->
                        MovieCardSearch(
                            movie,
                            onKnowMoreClick = {
                                viewModel.updateSelectedMovie(movie)
                                viewModel.showMoviePreview()
                            },
                            onAddToLibraryClick = {
                                viewModel.insertMovie(movie)
                            },
                            added = viewModel.viewModelLibrary.moviesExists(movie.id)
                        )
                    }
                }

                PreviewMovie(
                    isModalVisible = viewModel.isPopupVisible,
                    onCloseButtonClick = { viewModel.hideMoviePreview() },
                    movie = viewModel.selectedMovie
                )
                Spacer(modifier = Modifier.height(55.dp))
            }
        },
        bottomBar = {
            BottomNavigation(navController = navController)
        }
    )
}
