package com.example.moviestudio.ui.screens

import android.annotation.SuppressLint
import android.widget.Toast
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.TopAppBar
import androidx.compose.material3.TopAppBarDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.lifecycle.viewmodel.compose.viewModel
import androidx.navigation.NavController
import com.example.moviestudio.R
import com.example.moviestudio.ui.components.AlertDialogSuppression
import com.example.moviestudio.ui.components.BottomNavigation
import com.example.moviestudio.ui.theme.dark
import com.example.moviestudio.ui.theme.main
import com.example.moviestudio.ui.theme.second
import com.example.moviestudio.viewmodels.SettingsViewModel
import kotlinx.coroutines.launch

@SuppressLint("UnusedMaterial3ScaffoldPaddingParameter")
@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun Settings(navController: NavController) {
    val appName = stringResource(id = R.string.app_name)
    val pageName = stringResource(id = R.string.settings_undertitle)
    val txtButton = stringResource(id = R.string.settings_button_text)
    val txtModalTitle = stringResource(id = R.string.settings_modal_suppression_title)
    val txtModalText = stringResource(id = R.string.settings_modal_suppression_text)
    val toastText = stringResource(id = R.string.settings_toaster_suppression)
    val context = LocalContext.current

    var isDialogVisible by remember { mutableStateOf(false) }

    val viewModel = viewModel<SettingsViewModel>()

    Scaffold(
        modifier = Modifier.background(Color.Black),
        topBar = {
            TopAppBar(
                colors = TopAppBarDefaults.smallTopAppBarColors(
                    containerColor = main,
                    titleContentColor = Color.White,
                ),
                title = {
                    Column {
                        Text(text = appName, fontSize = 24.sp)
                        Text(text = pageName, fontSize = 16.sp)
                    }
                }
            )
        },
        content = {
            // Content with a Column containing a Button
            Column(
                modifier = Modifier
                    .background(color = dark)
                    .fillMaxSize()
                    .padding(start = 10.dp),
                horizontalAlignment = Alignment.CenterHorizontally,
                verticalArrangement = Arrangement.Center
            ) {
                Button(
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(6.dp),
                    onClick = {
                        isDialogVisible = true
                        //viewModel.deleteAppData()
                        //Toast.makeText(context, toastText, Toast.LENGTH_LONG).show()
                    },
                    colors = ButtonDefaults.buttonColors(containerColor = second)
                ) {
                    Text(text = txtButton)
                }
            }
        },
        bottomBar = {
            BottomNavigation(navController = navController)
        }
    )

    if (isDialogVisible) {
        AlertDialogSuppression(
            onDismissRequest = {
                isDialogVisible = false
            },
            onConfirmation = {
                viewModel.deleteAppData()
                Toast.makeText(context, toastText, Toast.LENGTH_LONG).show()
                isDialogVisible = false
            },
            dialogTitle = txtModalTitle,
            dialogText = txtModalText
        )
    }
}
