package com.example.moviestudio.viewmodels

import android.util.Log
import androidx.compose.foundation.gestures.rememberTransformableState
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateListOf
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.setValue
import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.moviestudio.Movie
import com.example.moviestudio.UserRating
import com.example.moviestudio.database.DatabaseProvider
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.flow.update
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext

class LibraryViewModel() : ViewModel() {

    val db = DatabaseProvider.getDatabase()

    var searchQuery by mutableStateOf("")
        private set

    var searchPublishDate by mutableStateOf("")
        private set

    var searchActor by mutableStateOf("")
        private set

    var searchGenre by mutableStateOf("")
        private set

    var isModalVisible by mutableStateOf(false)
        private set

    private var _moviesFlow = MutableStateFlow(fetchMovies())
    val movieFlow: StateFlow<List<Movie>> = _moviesFlow.asStateFlow()

    var selectedMovie by mutableStateOf(
        Movie(
            name = "", releaseDate = "", poster = "", description = "", genres = "", actors = ""
        )
    )

    fun updateSearchMovieName(value: String) {
        searchQuery = value
    }

    fun updateSearchPublishYear(value: String) {
        searchPublishDate = value
    }

    fun updateSearchActor(value: String) {
        searchActor = value
    }

    fun updateSearchGenre(value: String) {
        searchGenre = value
    }

    fun updateSelectedMovie(value: Movie) {
        selectedMovie = value
    }

    fun showMovieDetails() {
        isModalVisible = true
    }

    fun hideMovieDetails() {
        isModalVisible = false
    }

    fun deleteMovie(movieId: Long) {
        viewModelScope.launch(Dispatchers.IO) {
            db.movieDao().deleteMovie(movieId)
        }
        _moviesFlow.update {
            val mutableMovie = it.toMutableList()
            mutableMovie.filter { current -> current.id != movieId }
        }
    }

    fun fetchMovies(): List<Movie> {
        return db.movieDao().getAllMovies()
    }

    fun searchMoviesWithFilter() {
        viewModelScope.launch(Dispatchers.IO) {
            val movies = db.movieDao()
                .getMoviesByFilters(searchQuery, searchPublishDate, searchActor, searchGenre)
            _moviesFlow.value = movies
        }
    }

    fun clearInputs() {
        updateSearchActor("")
        updateSearchGenre("")
        updateSearchMovieName("")
        updateSearchPublishYear("")
    }

    fun moviesExists(id: Long): Boolean {
        _moviesFlow.value.forEach { movie: Movie ->
            if (movie.id == id) {
                return true
            }
        }
        return false
    }
}
