package com.example.moviestudio.viewmodels

import MovieAPI
import android.util.Log
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateListOf
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.setValue
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.moviestudio.Movie
import com.example.moviestudio.database.DatabaseProvider
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.launch
import kotlin.math.log

class SearchMovieViewModel : ViewModel() {
    val db = DatabaseProvider.getDatabase()

    val viewModelLibrary = LibraryViewModel()

    var isPopupVisible by mutableStateOf(false)
        private set

    var searchQuery by mutableStateOf("")
        private set

    private val displayPosterUrl = "https://image.tmdb.org/t/p/w500"

    private var _moviesFlow = MutableStateFlow(emptyList<Movie>())
    val movieFlow: StateFlow<List<Movie>> = _moviesFlow.asStateFlow()

    var selectedMovie by mutableStateOf(
        Movie(
            name = "",
            releaseDate = "",
            poster = "",
            description = "",
            genres = "",
            actors = ""
        )
    )

    var isSearchingMovie by mutableStateOf(false)

    fun updateSearchQuery(value: String) {
        searchQuery = value
    }

    fun showMoviePreview() {
        isPopupVisible = true
    }

    fun hideMoviePreview() {
        isPopupVisible = false
    }

    fun updateSelectedMovie(movie: Movie) {
        selectedMovie = movie
    }

    fun insertMovie(movie: Movie) {
        viewModelScope.launch(Dispatchers.IO) {
            db.movieDao().insertMovie(movie)
        }
    }

    fun searchMovies() {
        viewModelScope.launch(Dispatchers.IO) {
            val fetchedMovies = mutableStateListOf<Movie>()
            val resultMovies = MovieAPI.service.getMovies(searchQuery, "fr-FR")
            resultMovies.results.forEach { movieResult ->

                var poster = ""
                if (movieResult.poster_path != null)
                    poster = movieResult.poster_path
                // Get movie details
                var movie = Movie(
                    id = movieResult.id.toLong(),
                    name = movieResult.title,
                    releaseDate = movieResult.release_date, // convert this into european time
                    poster = poster,
                    description = movieResult.overview,
                    actors = "",
                    genres = ""
                )

                val resultGenres = MovieAPI.service.getMovieGenres(movieResult.id)
                val genresNames = resultGenres.genres.map { it.name }.joinToString(", ")
                movie.genres = genresNames

                val resultActors = MovieAPI.service.getMovieActors(movieResult.id)
                val actingActors = resultActors.cast.filter { it.known_for_department == "Acting" }
                val actorsNames = actingActors.map { it.name }.joinToString(", ")
                movie.actors = actorsNames
                fetchedMovies.add(movie)
            }
            _moviesFlow.value = fetchedMovies
            isSearchingMovie = false
        }
    }

    fun clearMovieList() {
        _moviesFlow.value = emptyList()
    }

    fun clearInput() {
        searchQuery = ""
    }

}


