package com.example.moviestudio.viewmodels

import android.media.Rating
import android.util.Log
import androidx.compose.runtime.MutableState
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.setValue
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.moviestudio.Movie
import com.example.moviestudio.UserRating
import com.example.moviestudio.database.DatabaseProvider
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch

class ShowMovieViewModel : ViewModel() {
    val db = DatabaseProvider.getDatabase()
    var rating: MutableState<UserRating> = mutableStateOf<UserRating>(
        UserRating(
            comment = "",
            rating = 1,
            movieId = -1
        )
    )

    var isDropdownExpanded by mutableStateOf(false)
        private set

    fun updateIsDropdownExpanded(value: Boolean) {
        isDropdownExpanded = value
    }

    fun updateRatingValue(value: Int) {
        rating.value = rating.value.copy(rating = value)
    }

    fun updateCommentValue(value: String) {
        rating.value = rating.value.copy(comment = value)
    }

    fun fetchRating(movieId: Long) {
        updateCommentValue("")
        updateRatingValue(1)
        viewModelScope.launch(Dispatchers.IO) {
            val fetched: UserRating? = db.ratingDao().getUserRatingById(movieId)
            fetched?.let {
                updateCommentValue(it.comment)
                updateRatingValue(it.rating)
            }
        }
    }


    fun insertRating(movie: Movie) {
        val newRating = rating.value.copy(movieId = movie.id)
        viewModelScope.launch(Dispatchers.IO) {
            db.ratingDao().insertUserRating(newRating)
        }
    }
}
